document.addEventListener('DOMContentLoaded', () => {
  const form = document.getElementById('ingredientForm');
  const ingredientsList = document.getElementById('ingredientsList');
  const totalCostElement = document.getElementById('totalCost');
  let ingredients = [];

  form.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const name = document.getElementById('ingredientName').value;
    const cost = parseFloat(document.getElementById('ingredientCost').value);
    const quantity = parseFloat(document.getElementById('ingredientQuantity').value);
    const unit = document.getElementById('ingredientUnit').value;

    addIngredient(name, cost, quantity, unit);
    form.reset();
  });

  function addIngredient(name, cost, quantity, unit) {
    const ingredient = {
      id: Date.now(),
      name,
      cost,
      quantity,
      unit
    };

    ingredients.push(ingredient);
    displayIngredients();
    updateTotal();
  }

  function displayIngredients() {
    ingredientsList.innerHTML = '';
    
    ingredients.forEach(ingredient => {
      const li = document.createElement('li');
      li.className = 'ingredient-item';
      li.innerHTML = `
        <span>${ingredient.name} - ${ingredient.quantity}${ingredient.unit} at $${ingredient.cost.toFixed(2)}</span>
        <button class="delete-btn" data-id="${ingredient.id}">Remove</button>
      `;
      ingredientsList.appendChild(li);
    });

    // Add event listeners to delete buttons
    document.querySelectorAll('.delete-btn').forEach(button => {
      button.addEventListener('click', (e) => {
        const id = parseInt(e.target.dataset.id);
        ingredients = ingredients.filter(ingredient => ingredient.id !== id);
        displayIngredients();
        updateTotal();
      });
    });
  }

  function updateTotal() {
    const total = ingredients.reduce((sum, ingredient) => sum + ingredient.cost, 0);
    totalCostElement.textContent = `$${total.toFixed(2)}`;
  }
});
